@@ -421,6 +421,7 @@ static void _normalize_gres_conf(List gres_list_conf, List gres_list_system)
 					 gres_record->count,
 					 gres_record->cpu_cnt,
 					 gres_record->cpus,
+					 gres_record->cpus_bitmap,
 					 gres_record->file,
 					 gres_record->type_name,
 					 gres_record->links);
@@ -433,6 +434,7 @@ static void _normalize_gres_conf(List gres_list_conf, List gres_list_system)
 					 gres_record->name, 1,
 					 gres_record->cpu_cnt,
 					 gres_record->cpus,
+					 gres_record->cpus_bitmap,
 					 gres_record->file,
 					 gres_record->type_name,
 					 gres_record->links);
@@ -443,6 +445,7 @@ static void _normalize_gres_conf(List gres_list_conf, List gres_list_system)
 						 gres_record->name, 1,
 						 gres_record->cpu_cnt,
 						 gres_record->cpus,
+						 gres_record->cpus_bitmap,
 						 gres_record->file,
 						 gres_record->type_name,
 						 gres_record->links);
@@ -458,7 +461,8 @@ static void _normalize_gres_conf(List gres_list_conf, List gres_list_system)
 			add_gres_to_list(gres_list_conf_single,
 					 gres_record->name, 1,
 					 gres_record->cpu_cnt,
-					 gres_record->cpus, hl_name,
+					 gres_record->cpus,
+					 gres_record->cpus_bitmap, hl_name,
 					 gres_record->type_name,
 					 gres_record->links);
 			free(hl_name);
@@ -622,6 +626,7 @@ static void _add_fake_gpus_from_file(List gres_list_system,
 		char *device_file = NULL;
 		char *type = NULL;
 		char *links = NULL;
+		bitstr_t *cpu_aff_mac_bitstr = NULL;
 		line_number++;
 
 		/*
@@ -680,9 +685,16 @@ static void _add_fake_gpus_from_file(List gres_list_system,
 			      " that the format is <type>|<sys_cpu_count>|"
 			      "<cpu_range>|<links>|<device_file>", line_number);
 
+		cpu_aff_mac_bitstr = bit_alloc(cpu_count);
+		if (bit_unfmt(cpu_aff_mac_bitstr, cpu_range))
+			fatal("%s: bit_unfmt() failed for CPU range: %s",
+			      __func__, cpu_range);
+
 		// Add the GPU specified by the parsed line
 		add_gres_to_list(gres_list_system, "gpu", 1, cpu_count,
-				 cpu_range, device_file, type, links);
+				 cpu_range, cpu_aff_mac_bitstr, device_file,
+				 type, links);
+		FREE_NULL_BITMAP(cpu_aff_mac_bitstr);
 		xfree(cpu_range);
 		xfree(device_file);
 		xfree(type);
@@ -935,6 +947,9 @@ extern void epilog_set_env(char ***epilog_env_ptr,
 	if (!gres_devices)
 		return;
 
+	if (epilog_info->node_cnt == 0)	/* no_consume */
+		return;
+
 	if (node_inx > epilog_info->node_cnt) {
 		error("%s: %s: bad node index (%d > %u)", plugin_type, __func__,
 		      node_inx, epilog_info->node_cnt);
