@@ -67,8 +67,6 @@
 #include "src/common/slurm_auth.h"
 #include "src/common/slurm_rlimits_info.h"
 #include "src/common/slurm_time.h"
-#include "src/common/tres_bind.h"
-#include "src/common/tres_frequency.h"
 #include "src/common/uid.h"
 #include "src/common/xmalloc.h"
 #include "src/common/xsignal.h"
@@ -965,20 +963,7 @@ static int _fill_job_desc_from_opts(job_desc_msg_t *desc)
 
 	if (opt.cpus_per_gpu)
 		xstrfmtcat(desc->cpus_per_tres, "gpu:%d", opt.cpus_per_gpu);
-	if (opt.gpu_bind)
-		xstrfmtcat(opt.tres_bind, "gpu:%s", opt.gpu_bind);
-	if (tres_bind_verify_cmdline(opt.tres_bind)) {
-		error("Invalid --tres-bind argument: %s. Ignored",
-		      opt.tres_bind);
-		xfree(opt.tres_bind);
-	}
 	desc->tres_bind = xstrdup(opt.tres_bind);
-	xfmt_tres_freq(&opt.tres_freq, "gpu", opt.gpu_freq);
-	if (tres_freq_verify_cmdline(opt.tres_freq)) {
-		error("Invalid --tres-freq argument: %s. Ignored",
-		      opt.tres_freq);
-		xfree(opt.tres_freq);
-	}
 	desc->tres_freq = xstrdup(opt.tres_freq);
 	xfmt_tres(&desc->tres_per_job,    "gpu", opt.gpus);
 	xfmt_tres(&desc->tres_per_node,   "gpu", opt.gpus_per_node);
